==> ec2-0.8.2-sources.jar: software/amazon/awscdk/services/ec2/ClassicLoadBalancer.java <==
package software.amazon.awscdk.services.ec2;
/**
 * A load balancer with a single listener
 * 
 * Routes to a fleet of of instances in a VPC.
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.ClassicLoadBalancer")
public class ClassicLoadBalancer extends software.amazon.awscdk.Construct implements software.amazon.awscdk.services.ec2.IConnectable {
    protected ClassicLoadBalancer(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public ClassicLoadBalancer(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.ClassicLoadBalancerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }
    /**
     * Add a backend to the load balancer
     * @return A ClassicListenerPort object that controls connections to the listener port
     */
    public software.amazon.awscdk.services.ec2.ClassicListenerPort addListener(final software.amazon.awscdk.services.ec2.ClassicLoadBalancerListener listener) {
        return this.jsiiCall("addListener", software.amazon.awscdk.services.ec2.ClassicListenerPort.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(listener, "listener is required")).toArray());
    }
    public void addTarget(final software.amazon.awscdk.services.ec2.IClassicLoadBalancerTarget target) {
        this.jsiiCall("addTarget", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(target, "target is required")).toArray());
    }
    /**
     * Control all connections from and to this load balancer
     */
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }
    public software.amazon.awscdk.services.ec2.IConnectionPeer getConnectionPeer() {
        return this.jsiiGet("connectionPeer", software.amazon.awscdk.services.ec2.IConnectionPeer.class);
    }
    /**
     * An object controlling specifically the connections for each listener added to this load balancer
     */
    public java.util.List<software.amazon.awscdk.services.ec2.ClassicListenerPort> getListenerPorts() {
        return this.jsiiGet("listenerPorts", java.util.List.class);
    }
    public software.amazon.awscdk.Token getLoadBalancerName() {
        return this.jsiiGet("loadBalancerName", software.amazon.awscdk.Token.class);
    }
    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerCanonicalHostedZoneName getLoadBalancerCanonicalHostedZoneName() {
        return this.jsiiGet("loadBalancerCanonicalHostedZoneName", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerCanonicalHostedZoneName.class);
    }
    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerDnsName getLoadBalancerDnsName() {
        return this.jsiiGet("loadBalancerDnsName", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerDnsName.class);
    }
    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupGroupName getLoadBalancerSourceSecurityGroupGroupName() {
        return this.jsiiGet("loadBalancerSourceSecurityGroupGroupName", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupGroupName.class);
    }
    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupOwnerAlias getLoadBalancerSourceSecurityGroupOwnerAlias() {
        return this.jsiiGet("loadBalancerSourceSecurityGroupOwnerAlias", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupOwnerAlias.class);
    }
}

==> ec2-0.9.0-sources.jar: software/amazon/awscdk/services/ec2/ClassicLoadBalancer.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A load balancer with a single listener
 * 
 * Routes to a fleet of of instances in a VPC.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:56:33.231Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.ClassicLoadBalancer")
public class ClassicLoadBalancer extends software.amazon.awscdk.Construct implements software.amazon.awscdk.services.ec2.IConnectable {
    protected ClassicLoadBalancer(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public ClassicLoadBalancer(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.ClassicLoadBalancerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    /**
     * Add a backend to the load balancer
     * @return A ClassicListenerPort object that controls connections to the listener port
     */
    public software.amazon.awscdk.services.ec2.ClassicListenerPort addListener(final software.amazon.awscdk.services.ec2.ClassicLoadBalancerListener listener) {
        return this.jsiiCall("addListener", software.amazon.awscdk.services.ec2.ClassicListenerPort.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(listener, "listener is required")).toArray());
    }

    public void addTarget(final software.amazon.awscdk.services.ec2.IClassicLoadBalancerTarget target) {
        this.jsiiCall("addTarget", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(target, "target is required")).toArray());
    }

    /**
     * Control all connections from and to this load balancer
     */
    @Override
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }

    /**
     * An object controlling specifically the connections for each listener added to this load balancer
     */
    public java.util.List<software.amazon.awscdk.services.ec2.ClassicListenerPort> getListenerPorts() {
        return this.jsiiGet("listenerPorts", java.util.List.class);
    }

    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerCanonicalHostedZoneName getLoadBalancerCanonicalHostedZoneName() {
        return this.jsiiGet("loadBalancerCanonicalHostedZoneName", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerCanonicalHostedZoneName.class);
    }

    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerDnsName getLoadBalancerDnsName() {
        return this.jsiiGet("loadBalancerDnsName", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerDnsName.class);
    }

    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerName getLoadBalancerName() {
        return this.jsiiGet("loadBalancerName", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerName.class);
    }

    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupGroupName getLoadBalancerSourceSecurityGroupGroupName() {
        return this.jsiiGet("loadBalancerSourceSecurityGroupGroupName", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupGroupName.class);
    }

    public software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupOwnerAlias getLoadBalancerSourceSecurityGroupOwnerAlias() {
        return this.jsiiGet("loadBalancerSourceSecurityGroupOwnerAlias", software.amazon.awscdk.services.elasticloadbalancing.LoadBalancerSourceSecurityGroupOwnerAlias.class);
    }
}
